use chrono::{DateTime, Utc};
use chrono_english::{parse_date_string, Dialect};

pub trait TuiValue: Sized {
	fn to_string(&self) -> String;
	fn from_str(s: &str) -> Option<Self>;
}

impl TuiValue for DateTime<Utc> {
	fn to_string(&self) -> String {
		self.format("%Y-%m-%d %H:%M:%S").to_string()
	}

	fn from_str(s: &str) -> Option<Self> {
		parse_date_string(s, Utc::now(), Dialect::Us).ok()
	}
}

impl TuiValue for String {
	fn to_string(&self) -> String {
		self.clone()
	}

	fn from_str(s: &str) -> Option<Self> {
		Some(s.to_owned())
	}
}

impl TuiValue for f64 {
	fn to_string(&self) -> String {
		format!("{self}")
	}

	fn from_str(s: &str) -> Option<Self> {
		s.parse().ok()
	}
}
